SweetHome3DJS Test

###

@{HomeFurniturePanel.nameLabel.text}
@{HomeFurniturePanel.nameVisibleCheckBox.text}
@{HomeFurniturePanel.descriptionLabel.text}
@{HomeFurniturePanel.priceLabel.text}
@{HomeFurniturePanel.valueAddedTaxPercentageLabel.text}

### @{HomeFurniturePanel.locationPanel.title}

@{HomeFurniturePanel.mirroredModelCheckBox.text} @{HomeFurniturePanel.basePlanItemCheckBox.text}

### @{HomeFurniturePanel.colorAndTexturePanel.title}

@{HomeFurniturePanel.defaultColorAndTextureRadioButton.text}
@{HomeFurniturePanel.colorRadioButton.text}
@{HomeFurniturePanel.textureRadioButton.text}
@{HomeFurniturePanel.modelMaterialsRadioButton.text}

### @{HomeFurniturePanel.orientationPanel.title}

@{HomeFurniturePanel.verticalRotationLabel.text}
@{HomeFurniturePanel.angleLabel.text}
@{HomeFurniturePanel.horizontalRotationLabel.text}
@{HomeFurniturePanel.pitchRadioButton.text}
@{HomeFurniturePanel.rollRadioButton.text}

### @{HomeFurniturePanel.sizePanel.title}

@{ImportedFurnitureWizardStepsPanel.keepProportionsCheckBox.text}

### @{HomeFurniturePanel.shininessPanel.title}

@{HomeFurniturePanel.defaultShininessRadioButton.text}
@{HomeFurniturePanel.mattRadioButton.text}
@{HomeFurniturePanel.shinyRadioButton.text}
@{HomeFurniturePanel.visibleCheckBox.text}

### @{ObserverCameraPanel.locationPanel.title}

### @{ObserverCameraPanel.anglesPanel.title}

@{ObserverCameraPanel.yawLabel.text}
@{ObserverCameraPanel.pitchLabel.text}
@{ObserverCameraPanel.fieldOfViewLabel.text}
@{ObserverCameraPanel.adjustObserverCameraElevationCheckBox.text}

### @{Home3DAttributesPanel.groundPanel.title}

@{Home3DAttributesPanel.groundColorRadioButton.text}
@{Home3DAttributesPanel.groundTextureRadioButton.text}
@{Home3DAttributesPanel.backgroundImageVisibleOnGround3DCheckBox.text}

### @{Home3DAttributesPanel.skyPanel.title}

@{Home3DAttributesPanel.skyColorRadioButton.text}
@{Home3DAttributesPanel.skyTextureRadioButton.text}

### @{Home3DAttributesPanel.renderingPanel.title}

@{Home3DAttributesPanel.brightnessLabel.text}
@{Home3DAttributesPanel.darkLabel.text}
@{Home3DAttributesPanel.brightLabel.text}
@{Home3DAttributesPanel.wallsTransparencyLabel.text}
@{Home3DAttributesPanel.opaqueLabel.text}
@{Home3DAttributesPanel.invisibleLabel.text}

### @{CompassPanel.compassRosePanel.title}

@{CompassPanel.visibleCheckBox.text}

### @{CompassPanel.geographicLocationPanel.title}

@{CompassPanel.latitudeLabel.text} @{CompassPanel.northDirectionLabel.text}
@{CompassPanel.longitudeLabel.text}
@{LevelPanel.viewableCheckBox.text} @{LevelPanel.nameLabel.text}

@{LevelPanel.levelsSummaryLabel.text}

@{LevelPanel.nameColumn} | @{LevelPanel.elevationColumn} | @{LevelPanel.floorThicknessColumn} | @{LevelPanel.heightColumn}
--- | --- | --- | ---

### @{WallPanel.startPointPanel.title}

### @{WallPanel.endPointPanel.title}

### @{WallPanel.leftSidePanel.title}

@{WallPanel.leftSideColorRadioButton.text}
@{WallPanel.leftSideTextureRadioButton.text}

@{WallPanel.leftSideMattRadioButton.text} @{WallPanel.leftSideShinyRadioButton.text}

### @{WallPanel.rightSidePanel.title}

@{WallPanel.rightSideColorRadioButton.text}
@{WallPanel.rightSideTextureRadioButton.text}

@{WallPanel.rightSideMattRadioButton.text} @{WallPanel.rightSideShinyRadioButton.text}

### @{WallPanel.topPanel.title}

@{WallPanel.patternLabel.text}
@{WallPanel.topColorLabel.text} @{WallPanel.topDefaultColorRadioButton.text} @{WallPanel.topColorRadioButton.text}

### @{WallPanel.heightPanel.title}

@{WallPanel.rectangularWallRadioButton.text}
@{WallPanel.slopingWallRadioButton.text}
@{WallPanel.slopingWallHeightAtStartLabel.text} @{WallPanel.slopingWallHeightAtEndLabel.text}

### @{RoomPanel.nameAndAreaPanel.title}

@{RoomPanel.nameLabel.text} @{RoomPanel.areaVisibleCheckBox.text}

### @{RoomPanel.floorPanel.title}

@{RoomPanel.floorVisibleCheckBox.text}
@{RoomPanel.floorColorRadioButton.text}
@{RoomPanel.floorTextureRadioButton.text}

@{RoomPanel.floorMattRadioButton.text} @{RoomPanel.floorShinyRadioButton.text}

### @{RoomPanel.ceilingPanel.title}

@{RoomPanel.ceilingVisibleCheckBox.text}
@{RoomPanel.ceilingColorRadioButton.text}
@{RoomPanel.ceilingTextureRadioButton.text}
@{RoomPanel.ceilingFlatCheckBox.text}

@{RoomPanel.ceilingMattRadioButton.text} @{RoomPanel.ceilingShinyRadioButton.text}

### @{RoomPanel.wallSidesPanel.title}

@{RoomPanel.splitSurroundingWallsCheckBox.text}
@{RoomPanel.wallSidesColorRadioButton.text}
@{RoomPanel.wallSidesTextureRadioButton.text}

@{RoomPanel.wallSidesMattRadioButton.text} @{RoomPanel.wallSidesShinyRadioButton.text}

### @{RoomPanel.wallSidesBaseboardPanel.title}

@{UserPreferencesPanel.languageLabel.text}
@{UserPreferencesPanel.unitLabel.text}
@{UserPreferencesPanel.currencyLabel.text}
@{UserPreferencesPanel.valueAddedTaxCheckBox.text}
@{UserPreferencesPanel.furnitureCatalogViewLabel.text}
@{UserPreferencesPanel.treeRadioButton.text} @{UserPreferencesPanel.listRadioButton.text}
@{UserPreferencesPanel.navigationPanelLabel.text}
@{UserPreferencesPanel.navigationPanelCheckBox.text}
@{UserPreferencesPanel.editingIn3DViewLabel.text}
@{UserPreferencesPanel.editingIn3DViewCheckBox.text}
@{UserPreferencesPanel.aerialViewCenteredOnSelectionLabel.text}
@{UserPreferencesPanel.aerialViewCenteredOnSelectionCheckBox.text}
@{UserPreferencesPanel.observerCameraSelectedAtChangeLabel.text}
@{UserPreferencesPanel.observerCameraSelectedAtChangeCheckBox.text}
@{UserPreferencesPanel.magnetismLabel.text}
@{UserPreferencesPanel.magnetismCheckBox.text}
@{UserPreferencesPanel.rulersLabel.text}
@{UserPreferencesPanel.rulersCheckBox.text}
@{UserPreferencesPanel.gridLabel.text}
@{UserPreferencesPanel.gridCheckBox.text}
@{UserPreferencesPanel.defaultFontNameLabel.text}
@{UserPreferencesPanel.furnitureIconLabel.text}
@{UserPreferencesPanel.catalogIconRadioButton.text}
@{UserPreferencesPanel.topViewRadioButton.text} @{UserPreferencesPanel.iconSizeLabel.text}
@{UserPreferencesPanel.roomRenderingLabel.text}
@{UserPreferencesPanel.monochromeRadioButton.text} @{UserPreferencesPanel.floorColorOrTextureRadioButton.text}
@{UserPreferencesPanel.newWallPatternLabel.text}
@{UserPreferencesPanel.newWallThicknessLabel.text}
@{UserPreferencesPanel.newWallHeightLabel.text}
@{UserPreferencesPanel.newFloorThicknessLabel.text}
@{PolylinePanel.arrowsStyleLabel.text}
@{PolylinePanel.joinStyleLabel.text}
@{PolylinePanel.dashStyleLabel.text}
@{PolylinePanel.dashOffsetLabel.text}
@{PolylinePanel.colorLabel.text}
@{PolylinePanel.visibleIn3DViewCheckBox.text}

### @{DimensionLinePanel.startPointPanel.title}

### @{DimensionLinePanel.endPointPanel.title}

@{DimensionLinePanel.planDimensionLineRadioButton.text} @{DimensionLinePanel.elevationDimensionLineRadioButton.text}

### @{DimensionLinePanel.stylePanel.title}

@{DimensionLinePanel.colorLabel.text}

### @{DimensionLinePanel.rendering3DPanel.title}

@{DimensionLinePanel.visibleIn3DViewCheckBox.text}
@{DimensionLinePanel.pitchLabel.text}
@{DimensionLinePanel.pitch0DegreeRadioButton.text} @{DimensionLinePanel.pitch90DegreeRadioButton.text}

### @{LabelPanel.textAndStylePanel.title}

@{LabelPanel.textLabel.text}
@{LabelPanel.alignmentLabel.text}
@{LabelPanel.leftAlignmentRadioButton.text} @{LabelPanel.centerAlignmentRadioButton.text} @{LabelPanel.rightAlignmentRadioButton.text}
@{LabelPanel.fontNameLabel.text}
@{LabelPanel.colorLabel.text}

### @{LabelPanel.rendering3DPanel.title}

@{LabelPanel.visibleIn3DViewCheckBox.text}
@{LabelPanel.pitchLabel.text}
@{LabelPanel.pitch0DegreeRadioButton.text} @{LabelPanel.pitch90DegreeRadioButton.text}